@@ -14,11 +14,40 @@ use 5.010;
 
 use Moose;
 use Moose::Util::TypeConstraints;
+use Time::Piece;
 
 coerce __PACKAGE__,
   from 'HashRef',
   via  { __PACKAGE__->new($_) };
 
+# Chosen format: yyyy-mm-dd
+subtype 'SVG::Timeline::DateStr',
+  as 'Str',
+  where   { m/ \d{4}-\d{2}-\d{2} /ax };
+
+subtype 'SVG::Timeline::YearMonthStr',
+  as 'Str',
+  where   { m/ \d{4}-\d{2} /ax };
+
+subtype 'SVG::Timeline::YearStr',
+  as 'Str',
+  where   { m/ \d{4} /as };
+
+subtype 'SVG::Timeline::Num',
+  as 'Num';
+
+coerce 'SVG::Timeline::DateStr',
+  from 'SVG::Timeline::YearStr',
+  via  { $_ . '-01-01' };
+
+coerce 'SVG::Timeline::DateStr',
+  from 'SVG::Timeline::YearMonthStr',
+  via  { $_ . '-01' };
+
+coerce 'SVG::Timeline::Num',
+  from 'SVG::Timeline::DateStr',
+  via  \&str2num;
+
 has index => (
   is => 'ro',
   isa => 'Int',
@@ -31,16 +60,26 @@ has text => (
   required => 1,
 );
 
+sub str2num {
+  my ($datestr) = @_;
+
+  my $date = Time::Piece->strptime($datestr, '%Y-%m-%d');
+
+  return $date->year + ( $date->yday / ($date->is_leap_year ? 366 : 365) );
+}
+
 has start => (
   is => 'ro',
-  isa => 'Int',
+  isa => 'SVG::Timeline::Num',
   required => 1,
+  coerce => 1,
 );
 
 has end => (
   is => 'ro',
-  isa => 'Int',
+  isa => 'SVG::Timeline::Num',
   required => 1,
+  coerce => 1,
 );
 
 has colour => (
